about summary refs log tree commit diff
path: root/src/test
diff options
context:
space:
mode:
authorFlorian Wilkens <floya@live.de>2014-12-19 21:52:10 +0100
committerFlorian Wilkens <floya@live.de>2014-12-22 12:58:55 +0100
commitf8cfd2480b69a1cc266fc91d0b60c825a9dc18a7 (patch)
tree6d0eff18d899f6a660797fa3fa4265fd59ad4ed7 /src/test
parent34d680009205de2302b902d8f9f5f7ae7a042f1a (diff)
downloadrust-f8cfd2480b69a1cc266fc91d0b60c825a9dc18a7.tar.gz
rust-f8cfd2480b69a1cc266fc91d0b60c825a9dc18a7.zip
Renaming of the Iter types as in RFC #344
libcore: slice::Items -> slice::Iter, slice::MutItems -> slice::IterMut
libcollections: *::Items -> *::Iter, *::MoveItems -> *::IntoIter, *::MutItems -> *::IterMut

This is of course a [breaking-change].
Diffstat (limited to 'src/test')
-rw-r--r--src/test/bench/shootout-k-nucleotide.rs2
-rw-r--r--src/test/compile-fail/resolve-conflict-type-vs-import.rs6
-rw-r--r--src/test/run-pass/issue-13167.rs2
3 files changed, 5 insertions, 5 deletions
diff --git a/src/test/bench/shootout-k-nucleotide.rs b/src/test/bench/shootout-k-nucleotide.rs
index 8521e2216e9..6aa6b02857f 100644
--- a/src/test/bench/shootout-k-nucleotide.rs
+++ b/src/test/bench/shootout-k-nucleotide.rs
@@ -130,7 +130,7 @@ struct Table {
 
 struct Items<'a> {
     cur: Option<&'a Entry>,
-    items: slice::Items<'a, Option<Box<Entry>>>,
+    items: slice::Iter<'a, Option<Box<Entry>>>,
 }
 
 impl Table {
diff --git a/src/test/run-pass/issue-13167.rs b/src/test/run-pass/issue-13167.rs
index be3ee0e0783..1282077028f 100644
--- a/src/test/run-pass/issue-13167.rs
+++ b/src/test/run-pass/issue-13167.rs
@@ -11,7 +11,7 @@
 use std::slice;
 
 pub struct PhfMapEntries<'a, T: 'a> {
-    iter: slice::Items<'a, (&'static str, T)>,
+    iter: slice::Iter<'a, (&'static str, T)>,
 }
 
 impl<'a, T> Iterator<(&'static str, &'a T)> for PhfMapEntries<'a, T> {
diff --git a/src/test/compile-fail/resolve-conflict-type-vs-import.rs b/src/test/compile-fail/resolve-conflict-type-vs-import.rs
index fa072fa62ab..de934286a7c 100644
--- a/src/test/compile-fail/resolve-conflict-type-vs-import.rs
+++ b/src/test/compile-fail/resolve-conflict-type-vs-import.rs
@@ -8,10 +8,10 @@
 // option. This file may not be copied, modified, or distributed
 // except according to those terms.
 
-use std::slice::Items;
-//~^ ERROR import `Items` conflicts with type in this module
+use std::slice::Iter;
+//~^ ERROR import `Iter` conflicts with type in this module
 
-struct Items;
+struct Iter;
 
 fn main() {
 }